SecretKey

Struct SecretKey 

pub struct SecretKey {
    pub sk: SecretKey,
}
A secret key.

Fields

sk: SecretKey

Implementations

Source

impl SecretKey

pub fn from_bytes(sk: &[u8]) -> Result<Self, WSError>

Create a secret key from raw bytes.

pub fn from_pem(pem: &str) -> Result<Self, WSError>

Deserialize a PEM-encoded secret key.

pub fn from_der(der: &[u8]) -> Result<Self, WSError>

Deserialize a DER-encoded secret key.

pub fn to_bytes(&self) -> Vec<u8>

Return the secret key as raw bytes.

pub fn to_pem(&self) -> String

Serialize the secret key using PEM encoding.

pub fn to_der(&self) -> Vec<u8>

Serialize the secret key using DER encoding.

pub fn from_file(file: impl AsRef<Path>) -> Result<Self, WSError>

Read a secret key from a file.

pub fn to_file(&self, file: impl AsRef<Path>) -> Result<(), WSError>

Save a secret key to a file.

pub fn from_openssh(lines: &str) -> Result<Self, WSError>

Parse an OpenSSH secret key.

pub fn from_openssh_file(file: impl AsRef<Path>) -> Result<Self, WSError>

Read an OpenSSH key from a file.

pub fn from_any(data: &[u8]) -> Result<Self, WSError>

Try to guess the secret key format.

pub fn from_any_file(file: impl AsRef<Path>) -> Result<Self, WSError>

Load a key from a file, trying to guess its format.

Source

impl SecretKey

pub fn sign_multi( &self, module: Module, key_id: Option<&Vec<u8>>, detached: bool, allow_extensions: bool, ) -> Result<(Module, Vec<u8>), WSError>

Sign a module with the secret key.

If the module was already signed, the new signature is added to the existing ones. key_id is the key identifier of the public key, to be stored with the signature. This parameter is optional.

detached prevents the signature from being embedded.

allow_extensions allows new sections to be added to the module later, while retaining the ability for the original module to be verified.

Source

impl SecretKey

pub fn sign( &self, module: Module, key_id: Option<&Vec<u8>>, ) -> Result<Module, WSError>

Sign a module with the secret key.

If the module was already signed, the signature is replaced.

key_id is the key identifier of the public key, to be stored with the signature. This parameter is optional.